@@ -20,25 +20,28 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -g -pipe -Wall '
-           '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector '
-           '--param=ssp-buffer-size=4 -Wformat -Wformat-security '
-           '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard -mfpu=neon '
-           '-mthumb -Wno-psabi -O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 '
-           '-fexceptions -fstack-protector --param=ssp-buffer-size=4 -Wformat '
-           '-Wformat-security -fmessage-length=0 -march=armv7-a '
+           '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector-strong '
+           '--param=ssp-buffer-size=4 -fstack-clash-protection -Wformat '
+           '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
+           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 '
+           '-g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
+           '-fstack-protector-strong --param=ssp-buffer-size=4 '
+           '-fstack-clash-protection -Wformat -Wformat-security '
+           '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
            '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
-           '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector '
-           '--param=ssp-buffer-size=4 -Wformat -Wformat-security '
-           '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard -mfpu=neon '
-           '-mthumb -Wno-psabi',
+           '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector-strong '
+           '--param=ssp-buffer-size=4 -fstack-clash-protection -Wformat '
+           '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
+           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                     '-fstack-protector --param=ssp-buffer-size=4 -Wformat '
-                     '-Wformat-security -fmessage-length=0 -march=armv7-a '
+                     '-fstack-protector-strong --param=ssp-buffer-size=4 '
+                     '-fstack-clash-protection -Wformat -Wformat-security '
+                     '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
                      '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
@@ -52,15 +55,16 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--enable-shared' '--with-ensurepip=no' "
                 "'--with-dbmliborder=bdb' '--with-system-ffi=yes' 'CFLAGS=-O2 "
                 '-g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                '-fstack-protector --param=ssp-buffer-size=4 -Wformat '
-                '-Wformat-security -fmessage-length=0 -march=armv7-a '
+                '-fstack-protector-strong --param=ssp-buffer-size=4 '
+                '-fstack-clash-protection -Wformat -Wformat-security '
+                '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
                 "-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi' "
                 "'PKG_CONFIG_PATH=:/usr/lib/pkgconfig:/usr/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git2/upstream/coverage.info',
- 'COVERAGE_REPORT': '/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git2/upstream/lcov-report',
+ 'COVERAGE_INFO': '/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git3/upstream/coverage.info',
+ 'COVERAGE_REPORT': '/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git3/upstream/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
@@ -608,9 +612,10 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPT': '-DNDEBUG -O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-        '-fstack-protector --param=ssp-buffer-size=4 -Wformat '
-        '-Wformat-security -fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
-        '-mfpu=neon -mthumb -Wno-psabi',
+        '-fstack-protector-strong --param=ssp-buffer-size=4 '
+        '-fstack-clash-protection -Wformat -Wformat-security '
+        '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
+        '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -642,38 +647,47 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
                              '-g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 '
-                             '-fexceptions -fstack-protector '
-                             '--param=ssp-buffer-size=4 -Wformat '
-                             '-Wformat-security -fmessage-length=0 '
-                             '-march=armv7-a -mfloat-abi=hard -mfpu=neon '
-                             '-mthumb -Wno-psabi -O2 -g -pipe -Wall '
-                             '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                             '-fstack-protector --param=ssp-buffer-size=4 '
-                             '-Wformat -Wformat-security -fmessage-length=0 '
-                             '-march=armv7-a -mfloat-abi=hard -mfpu=neon '
-                             '-mthumb -Wno-psabi -O2 -g -pipe -Wall '
-                             '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                             '-fstack-protector --param=ssp-buffer-size=4 '
-                             '-Wformat -Wformat-security -fmessage-length=0 '
-                             '-march=armv7-a -mfloat-abi=hard -mfpu=neon '
-                             '-mthumb -Wno-psabi -std=c99 -Wextra '
-                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-fexceptions -fstack-protector-strong '
+                             '--param=ssp-buffer-size=4 '
+                             '-fstack-clash-protection -Wformat '
+                             '-Wformat-security -Wl,-z,relro,-z,now '
+                             '-fmessage-length=0 -march=armv7-a '
+                             '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
+                             '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fexceptions -fstack-protector-strong '
+                             '--param=ssp-buffer-size=4 '
+                             '-fstack-clash-protection -Wformat '
+                             '-Wformat-security -Wl,-z,relro,-z,now '
+                             '-fmessage-length=0 -march=armv7-a '
+                             '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
+                             '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fexceptions -fstack-protector-strong '
+                             '--param=ssp-buffer-size=4 '
+                             '-fstack-clash-protection -Wformat '
+                             '-Wformat-security -Wl,-z,relro,-z,now '
+                             '-fmessage-length=0 -march=armv7-a '
+                             '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
+                             '-std=c99 -Wextra -Wno-unused-result '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration  '
                              '-I./Include/internal -I. -I./Include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -g -pipe -Wall '
-              '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector '
-              '--param=ssp-buffer-size=4 -Wformat -Wformat-security '
-              '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard -mfpu=neon '
-              '-mthumb -Wno-psabi -O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 '
-              '-fexceptions -fstack-protector --param=ssp-buffer-size=4 '
-              '-Wformat -Wformat-security -fmessage-length=0 -march=armv7-a '
+              '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector-strong '
+              '--param=ssp-buffer-size=4 -fstack-clash-protection -Wformat '
+              '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
+              '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
+              '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
+              '-fstack-protector-strong --param=ssp-buffer-size=4 '
+              '-fstack-clash-protection -Wformat -Wformat-security '
+              '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
               '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe '
-              '-Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector '
-              '--param=ssp-buffer-size=4 -Wformat -Wformat-security '
-              '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard -mfpu=neon '
-              '-mthumb -Wno-psabi',
+              '-Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
+              '-fstack-protector-strong --param=ssp-buffer-size=4 '
+              '-fstack-clash-protection -Wformat -Wformat-security '
+              '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
+              '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration  '
@@ -681,16 +695,19 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -g -pipe '
                    '-Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                   '-fstack-protector --param=ssp-buffer-size=4 -Wformat '
-                   '-Wformat-security -fmessage-length=0 -march=armv7-a '
+                   '-fstack-protector-strong --param=ssp-buffer-size=4 '
+                   '-fstack-clash-protection -Wformat -Wformat-security '
+                   '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
                    '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g '
                    '-pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                   '-fstack-protector --param=ssp-buffer-size=4 -Wformat '
-                   '-Wformat-security -fmessage-length=0 -march=armv7-a '
+                   '-fstack-protector-strong --param=ssp-buffer-size=4 '
+                   '-fstack-clash-protection -Wformat -Wformat-security '
+                   '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
                    '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g '
                    '-pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                   '-fstack-protector --param=ssp-buffer-size=4 -Wformat '
-                   '-Wformat-security -fmessage-length=0 -march=armv7-a '
+                   '-fstack-protector-strong --param=ssp-buffer-size=4 '
+                   '-fstack-clash-protection -Wformat -Wformat-security '
+                   '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
                    '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -std=c99 '
                    '-Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
@@ -705,16 +722,19 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -g '
                         '-pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                        '-fstack-protector --param=ssp-buffer-size=4 -Wformat '
-                        '-Wformat-security -fmessage-length=0 -march=armv7-a '
+                        '-fstack-protector-strong --param=ssp-buffer-size=4 '
+                        '-fstack-clash-protection -Wformat -Wformat-security '
+                        '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
                         '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g '
                         '-pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                        '-fstack-protector --param=ssp-buffer-size=4 -Wformat '
-                        '-Wformat-security -fmessage-length=0 -march=armv7-a '
+                        '-fstack-protector-strong --param=ssp-buffer-size=4 '
+                        '-fstack-clash-protection -Wformat -Wformat-security '
+                        '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
                         '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g '
                         '-pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                        '-fstack-protector --param=ssp-buffer-size=4 -Wformat '
-                        '-Wformat-security -fmessage-length=0 -march=armv7-a '
+                        '-fstack-protector-strong --param=ssp-buffer-size=4 '
+                        '-fstack-clash-protection -Wformat -Wformat-security '
+                        '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
                         '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
                         '-std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
@@ -728,7 +748,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git2/upstream',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git3/upstream',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -770,10 +790,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git2/upstream '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git3/upstream '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git2/upstream '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git3/upstream '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -795,8 +815,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git2/upstream',
- 'abs_srcdir': '/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git2/upstream',
+ 'abs_builddir': '/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git3/upstream',
+ 'abs_srcdir': '/home/abuild/rpmbuild/BUILD/python3-base-3.8.11+git3/upstream',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
